pub enum GrpcTimeoutConfigError {
InvalidField {
field: &'static str,
maximum_seconds: u64,
},
InvalidEnvironment,
EnvironmentOutOfRange,
UnrepresentableDeadline,
}Expand description
Invalid logical gRPC deadline configuration.
Variants
InvalidField
A programmatic field was zero, subsecond, or above its finite maximum.
Fields
InvalidEnvironment
The process override was not an exact supported ASCII decimal.
EnvironmentOutOfRange
The process override exceeded 3,600 seconds.
UnrepresentableDeadline
Absolute deadline arithmetic was not representable.