pub struct GrpcCallOptions {
pub class: GrpcTimeoutClass,
pub outcome: GrpcTimeoutOutcome,
pub enclosing: Option<GrpcEnclosingDeadline>,
}Expand description
Per-request profile, outcome, and optional enclosing budget.
Fields
class: GrpcTimeoutClassSelected logical profile.
outcome: GrpcTimeoutOutcomeSafety outcome if the call expires after possible dispatch.
enclosing: Option<GrpcEnclosingDeadline>Optional smaller enclosing absolute deadline.
Implementations
Sourceimpl GrpcCallOptions
impl GrpcCallOptions
Sourcepub const fn new(class: GrpcTimeoutClass, outcome: GrpcTimeoutOutcome) -> Self
pub const fn new(class: GrpcTimeoutClass, outcome: GrpcTimeoutOutcome) -> Self
Creates request options for a deadline class and safety outcome.
Sourcepub const fn enclosing(self, deadline: GrpcEnclosingDeadline) -> Self
pub const fn enclosing(self, deadline: GrpcEnclosingDeadline) -> Self
Adds an enclosing absolute deadline.
Sourcepub const fn ordinary_read() -> Self
pub const fn ordinary_read() -> Self
Ordinary read options.
Sourcepub const fn ordinary_mutation() -> Self
pub const fn ordinary_mutation() -> Self
Ordinary mutation options.
Sourcepub const fn stream_setup() -> Self
pub const fn stream_setup() -> Self
Stream setup options.